-- select one -- English Welsh Scottish Northern Irish Irish Gypsy or Irish Traveller Any other White background White and Black Caribbean White and Black African Any other Mixed or Multiple background Indian Pakistani Bangladeshi Chinese Any other Asian background African African American Caribbean Any other Black background Arab Hispanic Latino Native American Pacific Islander Any other ethnic group Prefer not to answer